import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface IntegerConfig extends cdktf.TerraformMetaArguments {
    /**
     * Arbitrary map of values that, when changed, will trigger recreation of resource.
     *
     * See [the main provider documentation](../index.html) for more information.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/integer#keepers Integer#keepers}
     *
     * @stability stable
     */
    readonly keepers?: {
        [key: string]: string;
    };
    /**
     * The maximum inclusive value of the range.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/integer#max Integer#max}
     *
     * @stability stable
     */
    readonly max: number;
    /**
     * The minimum inclusive value of the range.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/integer#min Integer#min}
     *
     * @stability stable
     */
    readonly min: number;
    /**
     * A custom seed to always produce the same value.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/integer#seed Integer#seed}
     *
     * @stability stable
     */
    readonly seed?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/random/r/integer random_integer}.
 *
 * @stability stable
 */
export declare class Integer extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/random/r/integer random_integer} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: IntegerConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _keepers?;
    /**
     * @stability stable
     */
    get keepers(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set keepers(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetKeepers(): void;
    /**
     * @stability stable
     */
    get keepersInput(): {
        [key: string]: string;
    } | undefined;
    private _max?;
    /**
     * @stability stable
     */
    get max(): number;
    /**
     * @stability stable
     */
    set max(value: number);
    /**
     * @stability stable
     */
    get maxInput(): number | undefined;
    private _min?;
    /**
     * @stability stable
     */
    get min(): number;
    /**
     * @stability stable
     */
    set min(value: number);
    /**
     * @stability stable
     */
    get minInput(): number | undefined;
    /**
     * @stability stable
     */
    get result(): number;
    private _seed?;
    /**
     * @stability stable
     */
    get seed(): string;
    /**
     * @stability stable
     */
    set seed(value: string);
    /**
     * @stability stable
     */
    resetSeed(): void;
    /**
     * @stability stable
     */
    get seedInput(): string | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
