import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface PetConfig extends cdktf.TerraformMetaArguments {
    /**
     * Arbitrary map of values that, when changed, will trigger recreation of resource.
     *
     * See [the main provider documentation](../index.html) for more information.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/pet#keepers Pet#keepers}
     *
     * @stability stable
     */
    readonly keepers?: {
        [key: string]: string;
    };
    /**
     * The length (in words) of the pet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/pet#length Pet#length}
     *
     * @stability stable
     */
    readonly length?: number;
    /**
     * A string to prefix the name with.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/pet#prefix Pet#prefix}
     *
     * @stability stable
     */
    readonly prefix?: string;
    /**
     * The character to separate words in the pet name.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/pet#separator Pet#separator}
     *
     * @stability stable
     */
    readonly separator?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/random/r/pet random_pet}.
 *
 * @stability stable
 */
export declare class Pet extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/random/r/pet random_pet} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: PetConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _keepers?;
    /**
     * @stability stable
     */
    get keepers(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set keepers(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetKeepers(): void;
    /**
     * @stability stable
     */
    get keepersInput(): {
        [key: string]: string;
    } | undefined;
    private _length?;
    /**
     * @stability stable
     */
    get length(): number;
    /**
     * @stability stable
     */
    set length(value: number);
    /**
     * @stability stable
     */
    resetLength(): void;
    /**
     * @stability stable
     */
    get lengthInput(): number | undefined;
    private _prefix?;
    /**
     * @stability stable
     */
    get prefix(): string;
    /**
     * @stability stable
     */
    set prefix(value: string);
    /**
     * @stability stable
     */
    resetPrefix(): void;
    /**
     * @stability stable
     */
    get prefixInput(): string | undefined;
    private _separator?;
    /**
     * @stability stable
     */
    get separator(): string;
    /**
     * @stability stable
     */
    set separator(value: string);
    /**
     * @stability stable
     */
    resetSeparator(): void;
    /**
     * @stability stable
     */
    get separatorInput(): string | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
