import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface ShuffleConfig extends cdktf.TerraformMetaArguments {
    /**
     * The list of strings to shuffle.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/shuffle#input Shuffle#input}
     *
     * @stability stable
     */
    readonly input: string[];
    /**
     * Arbitrary map of values that, when changed, will trigger recreation of resource.
     *
     * See [the main provider documentation](../index.html) for more information.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/shuffle#keepers Shuffle#keepers}
     *
     * @stability stable
     */
    readonly keepers?: {
        [key: string]: string;
    };
    /**
     * The number of results to return.
     *
     * Defaults to the number of items in the `input` list. If fewer items are requested, some elements will be excluded from the result. If more items are requested, items will be repeated in the result but not more frequently than the number of items in the input list.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/shuffle#result_count Shuffle#result_count}
     *
     * @stability stable
     */
    readonly resultCount?: number;
    /**
     * Arbitrary string with which to seed the random number generator, in order to produce less-volatile permutations of the list.
     *
     * *Important:** Even with an identical seed, it is not guaranteed that the same permutation will be produced across different versions of Terraform. This argument causes the result to be *less volatile*, but not fixed for all time.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/shuffle#seed Shuffle#seed}
     *
     * @stability stable
     */
    readonly seed?: string;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/random/r/shuffle random_shuffle}.
 *
 * @stability stable
 */
export declare class Shuffle extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/random/r/shuffle random_shuffle} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: ShuffleConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _input?;
    /**
     * @stability stable
     */
    get input(): string[];
    /**
     * @stability stable
     */
    set input(value: string[]);
    /**
     * @stability stable
     */
    get inputInput(): string[] | undefined;
    private _keepers?;
    /**
     * @stability stable
     */
    get keepers(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set keepers(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetKeepers(): void;
    /**
     * @stability stable
     */
    get keepersInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    get result(): string[];
    private _resultCount?;
    /**
     * @stability stable
     */
    get resultCount(): number;
    /**
     * @stability stable
     */
    set resultCount(value: number);
    /**
     * @stability stable
     */
    resetResultCount(): void;
    /**
     * @stability stable
     */
    get resultCountInput(): number | undefined;
    private _seed?;
    /**
     * @stability stable
     */
    get seed(): string;
    /**
     * @stability stable
     */
    set seed(value: string);
    /**
     * @stability stable
     */
    resetSeed(): void;
    /**
     * @stability stable
     */
    get seedInput(): string | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
