import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface StringResourceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Arbitrary map of values that, when changed, will trigger recreation of resource.
     *
     * See [the main provider documentation](../index.html) for more information.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/string#keepers StringResource#keepers}
     *
     * @stability stable
     */
    readonly keepers?: {
        [key: string]: string;
    };
    /**
     * The length of the string desired.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/string#length StringResource#length}
     *
     * @stability stable
     */
    readonly length: number;
    /**
     * Include lowercase alphabet characters in the result.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/string#lower StringResource#lower}
     *
     * @stability stable
     */
    readonly lower?: boolean | cdktf.IResolvable;
    /**
     * Minimum number of lowercase alphabet characters in the result.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/string#min_lower StringResource#min_lower}
     *
     * @stability stable
     */
    readonly minLower?: number;
    /**
     * Minimum number of numeric characters in the result.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/string#min_numeric StringResource#min_numeric}
     *
     * @stability stable
     */
    readonly minNumeric?: number;
    /**
     * Minimum number of special characters in the result.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/string#min_special StringResource#min_special}
     *
     * @stability stable
     */
    readonly minSpecial?: number;
    /**
     * Minimum number of uppercase alphabet characters in the result.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/string#min_upper StringResource#min_upper}
     *
     * @stability stable
     */
    readonly minUpper?: number;
    /**
     * Include numeric characters in the result.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/string#number StringResource#number}
     *
     * @stability stable
     */
    readonly number?: boolean | cdktf.IResolvable;
    /**
     * Supply your own list of special characters to use for string generation.
     *
     * This overrides the default character list in the special argument.  The `special` argument must still be set to true for any overwritten characters to be used in generation.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/string#override_special StringResource#override_special}
     *
     * @stability stable
     */
    readonly overrideSpecial?: string;
    /**
     * Include special characters in the result. These are `!@#$%&*()-_=+[]{}<>:?`.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/string#special StringResource#special}
     *
     * @stability stable
     */
    readonly special?: boolean | cdktf.IResolvable;
    /**
     * Include uppercase alphabet characters in the result.
     *
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/random/r/string#upper StringResource#upper}
     *
     * @stability stable
     */
    readonly upper?: boolean | cdktf.IResolvable;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/random/r/string random_string}.
 *
 * @stability stable
 */
export declare class StringResource extends cdktf.TerraformResource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/random/r/string random_string} Resource.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config: StringResourceConfig);
    /**
     * @stability stable
     */
    get id(): string;
    private _keepers?;
    /**
     * @stability stable
     */
    get keepers(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set keepers(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetKeepers(): void;
    /**
     * @stability stable
     */
    get keepersInput(): {
        [key: string]: string;
    } | undefined;
    private _length?;
    /**
     * @stability stable
     */
    get length(): number;
    /**
     * @stability stable
     */
    set length(value: number);
    /**
     * @stability stable
     */
    get lengthInput(): number | undefined;
    private _lower?;
    /**
     * @stability stable
     */
    get lower(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set lower(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetLower(): void;
    /**
     * @stability stable
     */
    get lowerInput(): boolean | cdktf.IResolvable | undefined;
    private _minLower?;
    /**
     * @stability stable
     */
    get minLower(): number;
    /**
     * @stability stable
     */
    set minLower(value: number);
    /**
     * @stability stable
     */
    resetMinLower(): void;
    /**
     * @stability stable
     */
    get minLowerInput(): number | undefined;
    private _minNumeric?;
    /**
     * @stability stable
     */
    get minNumeric(): number;
    /**
     * @stability stable
     */
    set minNumeric(value: number);
    /**
     * @stability stable
     */
    resetMinNumeric(): void;
    /**
     * @stability stable
     */
    get minNumericInput(): number | undefined;
    private _minSpecial?;
    /**
     * @stability stable
     */
    get minSpecial(): number;
    /**
     * @stability stable
     */
    set minSpecial(value: number);
    /**
     * @stability stable
     */
    resetMinSpecial(): void;
    /**
     * @stability stable
     */
    get minSpecialInput(): number | undefined;
    private _minUpper?;
    /**
     * @stability stable
     */
    get minUpper(): number;
    /**
     * @stability stable
     */
    set minUpper(value: number);
    /**
     * @stability stable
     */
    resetMinUpper(): void;
    /**
     * @stability stable
     */
    get minUpperInput(): number | undefined;
    private _number?;
    /**
     * @stability stable
     */
    get number(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set number(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetNumber(): void;
    /**
     * @stability stable
     */
    get numberInput(): boolean | cdktf.IResolvable | undefined;
    private _overrideSpecial?;
    /**
     * @stability stable
     */
    get overrideSpecial(): string;
    /**
     * @stability stable
     */
    set overrideSpecial(value: string);
    /**
     * @stability stable
     */
    resetOverrideSpecial(): void;
    /**
     * @stability stable
     */
    get overrideSpecialInput(): string | undefined;
    /**
     * @stability stable
     */
    get result(): string;
    private _special?;
    /**
     * @stability stable
     */
    get special(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set special(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetSpecial(): void;
    /**
     * @stability stable
     */
    get specialInput(): boolean | cdktf.IResolvable | undefined;
    private _upper?;
    /**
     * @stability stable
     */
    get upper(): boolean | cdktf.IResolvable;
    /**
     * @stability stable
     */
    set upper(value: boolean | cdktf.IResolvable);
    /**
     * @stability stable
     */
    resetUpper(): void;
    /**
     * @stability stable
     */
    get upperInput(): boolean | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
